Object.assign(window.search, {"doc_urls":["index.html#pasta_curves","index.html#documentation","index.html#minimum-supported-rust-version","index.html#curve-descriptions","index.html#license","index.html#contribution","design.html#design","design.html#note-on-language","design/implementation.html#implementation","design/implementation/fields.html#fields","design/implementation/fields.html#sarkar-square-root-algorithm-table-based-variant","design/implementation/fields.html#i--0-1","design/implementation/fields.html#i--2","design/implementation/fields.html#i--3","design/implementation/fields.html#final-result"],"index":{"documentStore":{"docInfo":{"0":{"body":16,"breadcrumbs":2,"title":1},"1":{"body":0,"breadcrumbs":2,"title":1},"10":{"body":56,"breadcrumbs":10,"title":7},"11":{"body":8,"breadcrumbs":5,"title":2},"12":{"body":6,"breadcrumbs":4,"title":1},"13":{"body":6,"breadcrumbs":4,"title":1},"14":{"body":29,"breadcrumbs":5,"title":2},"2":{"body":14,"breadcrumbs":5,"title":4},"3":{"body":63,"breadcrumbs":3,"title":2},"4":{"body":16,"breadcrumbs":2,"title":1},"5":{"body":21,"breadcrumbs":2,"title":1},"6":{"body":0,"breadcrumbs":2,"title":1},"7":{"body":64,"breadcrumbs":3,"title":2},"8":{"body":0,"breadcrumbs":3,"title":1},"9":{"body":26,"breadcrumbs":4,"title":1}},"docs":{"0":{"body":"This crate provides an implementation of the Pasta elliptic curve constructions, Pallas and Vesta. More details about the Pasta curves can be found in this blog post .","breadcrumbs":"Pasta » pasta_curves","id":"0","title":"pasta_curves"},"1":{"body":"","breadcrumbs":"Pasta » Documentation","id":"1","title":"Documentation"},"10":{"body":"We use a technique from Sarkar2020 to compute square roots in pasta_curves. The intuition behind the algorithm is that we can split the task into computing square roots in each multiplicative subgroup. Suppose we want to find the square root of u modulo one of the Pasta primes p, where u is a non-zero square in Zp×​. We define a 2S root of unity g=zT where z is a non-square in Zp×​, and precompute the following tables: gtab=⎣⎡​g0(g28)0(g216)0(g224)0​g1(g28)1(g216)1(g224)1​............​g28−1(g28)28−1(g216)28−1(g224)28−1​⎦⎤​ invtab=[(g2−24)0​(g2−24)1​...​(g2−24)28−1​] Let v=u(T−1)/2. We can then define x=uv⋅v=uT as an element of the 2S multiplicative subgroup. Let x3​=x,x2​=x328​,x1​=x228​,x0​=x128​.","breadcrumbs":"Design » Implementation » Fields » Sarkar square-root algorithm (table-based variant)","id":"10","title":"Sarkar square-root algorithm (table-based variant)"},"11":{"body":"Using invtab, we lookup t0​ such that x0​=(g2−24)t0​⟹x0​⋅gt0​⋅224=1. Define α1​=x1​⋅(g216)t0​.","breadcrumbs":"Design » Implementation » Fields » i = 0, 1","id":"11","title":"i = 0, 1"},"12":{"body":"Lookup t1​ s.t. α1​=(g2−24)t1​​⟹x1​⋅(g216)t0​=(g2−24)t1​⟹x1​⋅g(t0​+28⋅t1​)⋅216=1.​ Define α2​=x2​⋅(g28)t0​+28⋅t1​.","breadcrumbs":"Design » Implementation » Fields » i = 2","id":"12","title":"i = 2"},"13":{"body":"Lookup t2​ s.t. α2​=(g2−24)t2​​⟹x2​⋅(g28)t0​+28⋅t1​=(g2−24)t2​⟹x2​⋅g(t0​+28⋅t1​+216⋅t2​)⋅28=1.​ Define α3​=x3​⋅gt0​+28⋅t1​+216⋅t2​.","breadcrumbs":"Design » Implementation » Fields » i = 3","id":"13","title":"i = 3"},"14":{"body":"Lookup t3​ such that α3​=(g2−24)t3​​⟹x3​⋅gt0​+28⋅t1​+216⋅t2​=(g2−24)t3​⟹x3​⋅gt0​+28⋅t1​+216⋅t2​+224⋅t3​=1.​ Let t=t0​+28⋅t1​+216⋅t2​+224⋅t3​. We can now write x3​⋅gt=1​⟹⟹⟹⟹​x3​uv2uvuv⋅gt/2​====​g−tg−tv−1⋅g−tv−1⋅g−t/2.​ Squaring the RHS, we observe that (v−1g−t/2)2=v−2g−t=u. Therefore, the square root of u is uv⋅gt/2; the first part we computed earlier, and the second part can be computed with three multiplications using lookups in gtab.","breadcrumbs":"Design » Implementation » Fields » Final result","id":"14","title":"Final result"},"2":{"body":"Requires Rust 1.56 or higher. Minimum supported Rust version can be changed in the future, but it will be done with a minor version bump.","breadcrumbs":"Pasta » Minimum Supported Rust Version","id":"2","title":"Minimum Supported Rust Version"},"3":{"body":"Pallas: y2 = x3 + 5 over GF(0x40000000000000000000000000000000224698fc094cf91b992d30ed00000001). Vesta: y2 = x3 + 5 over GF(0x40000000000000000000000000000000224698fc0994a8dd8c46eb2100000001). The Pasta curves form a cycle with one another: the order of each curve is exactly the base field of the other. This property is critical to the efficiency of recursive proof systems. They are designed to be highly 2-adic, meaning that a large power-of-two multiplicative subgroup exists in each field. This is important for the performance of polynomial arithmetic over their scalar fields and is essential for protocols similar to PLONK. These curves can be reproducibly obtained using a curve search utility we’ve published .","breadcrumbs":"Pasta » Curve Descriptions","id":"3","title":"Curve Descriptions"},"4":{"body":"Licensed under either of Apache License, Version 2.0, ( LICENSE-APACHE or http://www.apache.org/licenses/LICENSE-2.0) MIT license ( LICENSE-MIT or http://opensource.org/licenses/MIT) at your option.","breadcrumbs":"Pasta » License","id":"4","title":"License"},"5":{"body":"Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.","breadcrumbs":"Pasta » Contribution","id":"5","title":"Contribution"},"6":{"body":"","breadcrumbs":"Design » Design","id":"6","title":"Design"},"7":{"body":"We use slightly different language than others to describe PLONK concepts. Here's the overview: We like to think of PLONK-like arguments as tables, where each column corresponds to a \"wire\". We refer to entries in this table as \"cells\". We like to call \"selector polynomials\" and so on \"fixed columns\" instead. We then refer specifically to a \"selector constraint\" when a cell in a fixed column is being used to control whether a particular constraint is enabled in that row. We call the other polynomials \"advice columns\" usually, when they're populated by the prover. We use the term \"rule\" to refer to a \"gate\" like A(X)⋅qA​(X)+B(X)⋅qB​(X)+A(X)⋅B(X)⋅qM​(X)+C(X)⋅qC​(X)=0. TODO: Check how consistent we are with this, and update the code and docs to match.","breadcrumbs":"Design » Note on Language","id":"7","title":"Note on Language"},"8":{"body":"","breadcrumbs":"Design » Implementation » Implementation","id":"8","title":"Implementation"},"9":{"body":"The Pasta curves are designed to be highly 2-adic, meaning that a large 2S multiplicative subgroup exists in each field. That is, we can write p−1≡2S⋅T with T odd. For both Pallas and Vesta, S=32; this helps to simplify the field implementations.","breadcrumbs":"Design » Implementation » Fields » Fields","id":"9","title":"Fields"}},"length":15,"save":true},"fields":["title","body","breadcrumbs"],"index":{"body":{"root":{"0":{"df":1,"docs":{"11":{"tf":1.0}}},"1":{".":{"5":{"6":{"df":1,"docs":{"2":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":1,"docs":{"11":{"tf":1.0}},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"(":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{")":{"df":0,"docs":{},"⋅":{"2":{"1":{"6":{"=":{"1":{"df":1,"docs":{"12":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"df":0,"docs":{},"t":{"0":{"df":1,"docs":{"11":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"2":{".":{"0":{"df":2,"docs":{"4":{"tf":1.4142135623730951},"5":{"tf":1.0}}},"df":0,"docs":{}},"df":3,"docs":{"12":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}},"s":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"9":{"tf":1.0}}},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"(":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{")":{"df":0,"docs":{},"⋅":{"2":{"8":{"=":{"1":{"df":1,"docs":{"13":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":1,"docs":{"12":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"3":{"df":1,"docs":{"13":{"tf":1.0}},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"+":{"2":{"2":{"4":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"3":{"df":0,"docs":{},"​":{"=":{"1":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":1,"docs":{"13":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"5":{"df":1,"docs":{"3":{"tf":1.4142135623730951}}},"a":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"a":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"+":{"b":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"b":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"+":{"a":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"b":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"df":0,"docs":{},"m":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"+":{"c":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"c":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"=":{"0":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"b":{"df":0,"docs":{},"o":{"df":0,"docs":{},"v":{"df":1,"docs":{"5":{"tf":1.0}}}}},"d":{"d":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"c":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}},"v":{"df":0,"docs":{},"i":{"c":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{},"l":{"df":0,"docs":{},"g":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"m":{"df":1,"docs":{"10":{"tf":1.4142135623730951}}}}}}}}}},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"p":{"a":{"c":{"df":0,"docs":{},"h":{"df":2,"docs":{"4":{"tf":1.4142135623730951},"5":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{}},"r":{"df":0,"docs":{},"g":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}}}},"b":{"a":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":2,"docs":{"10":{"tf":1.0},"3":{"tf":1.0}}}}},"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}},"h":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}}}}},"l":{"df":0,"docs":{},"o":{"df":0,"docs":{},"g":{"df":1,"docs":{"0":{"tf":1.0}}}}},"o":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":1,"docs":{"9":{"tf":1.0}}}}},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":1,"docs":{"2":{"tf":1.0}}}}}},"c":{"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}},"h":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"g":{"df":1,"docs":{"2":{"tf":1.0}}}}},"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"k":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"o":{"d":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{},"l":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"n":{"df":1,"docs":{"7":{"tf":2.0}}}}}},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"14":{"tf":1.4142135623730951}}}}}},"n":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}}}},"d":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{},"s":{"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}}},"t":{"df":0,"docs":{},"r":{"a":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}}},"df":0,"docs":{},"u":{"c":{"df":0,"docs":{},"t":{"df":1,"docs":{"0":{"tf":1.0}}}},"df":0,"docs":{}}}}},"t":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"b":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.4142135623730951}}}}},"df":0,"docs":{}},"o":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}}}}},"r":{"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"df":0,"docs":{},"p":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}}}}}}}}},"r":{"a":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"0":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"c":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}}}}},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":3,"docs":{"0":{"tf":1.4142135623730951},"3":{"tf":2.23606797749979},"9":{"tf":1.0}}}}},"y":{"c":{"df":0,"docs":{},"l":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":5,"docs":{"10":{"tf":1.4142135623730951},"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"5":{"tf":1.0}}}}},"s":{"c":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"b":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"n":{"df":3,"docs":{"3":{"tf":1.0},"6":{"tf":1.0},"9":{"tf":1.0}}}}}},"t":{"a":{"df":0,"docs":{},"i":{"df":0,"docs":{},"l":{"df":1,"docs":{"0":{"tf":1.0}}}}},"df":0,"docs":{}}},"i":{"df":0,"docs":{},"f":{"df":0,"docs":{},"f":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}}}}},"o":{"c":{"df":1,"docs":{"7":{"tf":1.0}},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"1":{"tf":1.0}}}}}}}},"df":0,"docs":{},"n":{"df":0,"docs":{},"e":{"df":1,"docs":{"2":{"tf":1.0}}}}},"u":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"5":{"tf":1.0}}}},"df":0,"docs":{}}},"df":0,"docs":{},"e":{"a":{"c":{"df":0,"docs":{},"h":{"df":4,"docs":{"10":{"tf":1.0},"3":{"tf":1.4142135623730951},"7":{"tf":1.0},"9":{"tf":1.0}}}},"df":0,"docs":{},"r":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"14":{"tf":1.0}}}}}}}},"df":0,"docs":{},"f":{"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}}},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}}},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"0":{"tf":1.0}}}}}}},"n":{"a":{"b":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{},"t":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"df":1,"docs":{"7":{"tf":1.0}}}}}},"s":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}},"x":{"a":{"c":{"df":0,"docs":{},"t":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"df":0,"docs":{}},"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}}},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":1,"docs":{"5":{"tf":1.0}}}}}}},"df":0,"docs":{}}}}}},"f":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"d":{"df":2,"docs":{"3":{"tf":1.7320508075688772},"9":{"tf":1.7320508075688772}}},"df":0,"docs":{}}},"n":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"14":{"tf":1.0}}}},"d":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"r":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.0}}}}},"x":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}},"o":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":0,"docs":{},"o":{"df":0,"docs":{},"w":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"r":{"df":0,"docs":{},"m":{"df":1,"docs":{"3":{"tf":1.0}}}},"u":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"0":{"tf":1.0}}},"df":0,"docs":{}}}},"u":{"df":0,"docs":{},"t":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}}}}},"g":{"=":{"df":0,"docs":{},"z":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"a":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}}},"df":0,"docs":{},"f":{"(":{"0":{"df":0,"docs":{},"x":{"4":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"2":{"2":{"4":{"6":{"9":{"8":{"df":0,"docs":{},"f":{"c":{"0":{"9":{"4":{"c":{"df":0,"docs":{},"f":{"9":{"1":{"b":{"9":{"9":{"2":{"d":{"3":{"0":{"df":0,"docs":{},"e":{"d":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"1":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"9":{"4":{"a":{"8":{"d":{"d":{"8":{"c":{"4":{"6":{"df":0,"docs":{},"e":{"b":{"2":{"1":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"1":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"t":{"a":{"b":{"=":{"df":0,"docs":{},"⎣":{"df":0,"docs":{},"⎡":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"0":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"0":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"0":{"(":{"df":0,"docs":{},"g":{"2":{"2":{"4":{")":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"2":{"4":{")":{"1":{"df":0,"docs":{},"​":{".":{".":{".":{".":{".":{".":{".":{".":{".":{".":{".":{".":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"2":{"4":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"df":0,"docs":{},"p":{"df":1,"docs":{"9":{"tf":1.0}}}},"r":{"df":0,"docs":{},"e":{"'":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}}}},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}},"l":{"df":0,"docs":{},"i":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}}}}},"t":{"df":0,"docs":{},"t":{"df":0,"docs":{},"p":{":":{"/":{"/":{"df":0,"docs":{},"o":{"df":0,"docs":{},"p":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":0,"docs":{},"o":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"c":{"df":0,"docs":{},"e":{".":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"g":{"/":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"/":{"df":0,"docs":{},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"4":{"tf":1.0}}}}}},"df":0,"docs":{}}}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}}}}},"w":{"df":0,"docs":{},"w":{"df":0,"docs":{},"w":{".":{"a":{"df":0,"docs":{},"p":{"a":{"c":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{".":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"g":{"/":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"/":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":1,"docs":{"4":{"tf":1.0}}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":3,"docs":{"0":{"tf":1.0},"8":{"tf":1.0},"9":{"tf":1.0}}}}}}}},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"n":{"c":{"df":0,"docs":{},"l":{"df":0,"docs":{},"u":{"df":0,"docs":{},"s":{"df":1,"docs":{"5":{"tf":1.0}}}}}},"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"a":{"d":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}},"t":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"5":{"tf":1.0}}}}}}}},"u":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"v":{"df":0,"docs":{},"t":{"a":{"b":{"=":{"[":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"0":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"1":{"df":0,"docs":{},"​":{".":{".":{".":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":1,"docs":{"11":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"l":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"g":{"df":0,"docs":{},"u":{"a":{"df":0,"docs":{},"g":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}},"df":0,"docs":{}}}},"r":{"df":0,"docs":{},"g":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":2,"docs":{"4":{"tf":2.449489742783178},"5":{"tf":1.4142135623730951}}}}}},"df":0,"docs":{}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"k":{"df":0,"docs":{},"u":{"df":0,"docs":{},"p":{"df":4,"docs":{"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"14":{"tf":1.4142135623730951}}}}}}}},"m":{"a":{"df":0,"docs":{},"t":{"c":{"df":0,"docs":{},"h":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"df":0,"docs":{},"e":{"a":{"df":0,"docs":{},"n":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}},"df":0,"docs":{}},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":1,"docs":{"2":{"tf":1.4142135623730951}}}}}},"o":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}}},"t":{"df":1,"docs":{"4":{"tf":1.4142135623730951}}}},"o":{"d":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"o":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":1,"docs":{"0":{"tf":1.0}}}}},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"p":{"df":0,"docs":{},"l":{"df":4,"docs":{"10":{"tf":1.4142135623730951},"14":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}}}}}}}},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"10":{"tf":1.4142135623730951}}},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"w":{"df":1,"docs":{"14":{"tf":1.0}}}}},"o":{"b":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":1,"docs":{"14":{"tf":1.0}}}}}},"t":{"a":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":1,"docs":{"3":{"tf":1.0}}}}},"df":0,"docs":{}}},"d":{"d":{"df":1,"docs":{"9":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{},"n":{"df":2,"docs":{"10":{"tf":1.0},"3":{"tf":1.0}}},"p":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"4":{"tf":1.0}}}}}}},"r":{"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}}},"df":0,"docs":{}},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}},"w":{"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":1,"docs":{"5":{"tf":1.0}}}}}}}}},"v":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.7320508075688772}},"v":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"w":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}}}},"p":{"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"a":{"df":3,"docs":{"0":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}}},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.4142135623730951}},"i":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}},"s":{"df":0,"docs":{},"t":{"a":{"_":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":2,"docs":{"0":{"tf":1.0},"10":{"tf":1.0}}}}}},"df":0,"docs":{}},"df":4,"docs":{"0":{"tf":1.4142135623730951},"10":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}}}},"df":1,"docs":{"10":{"tf":1.0}},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"f":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"m":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}},"l":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":0,"docs":{},"k":{"df":2,"docs":{"3":{"tf":1.0},"7":{"tf":1.4142135623730951}}}}}},"o":{"df":0,"docs":{},"l":{"df":0,"docs":{},"y":{"df":0,"docs":{},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"m":{"df":0,"docs":{},"i":{"df":2,"docs":{"3":{"tf":1.0},"7":{"tf":1.4142135623730951}}}}}}}},"p":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}}},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"0":{"tf":1.0}}}},"w":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"r":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}}}},"df":0,"docs":{}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":1,"docs":{"10":{"tf":1.0}}}}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"f":{"df":1,"docs":{"3":{"tf":1.0}}}},"p":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"t":{"df":0,"docs":{},"o":{"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"l":{"df":1,"docs":{"3":{"tf":1.0}}}}},"df":0,"docs":{}}},"v":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}},"i":{"d":{"df":1,"docs":{"0":{"tf":1.0}}},"df":0,"docs":{}}}}},"u":{"b":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":0,"docs":{},"h":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"df":0,"docs":{}},"−":{"1":{"df":0,"docs":{},"≡":{"2":{"df":0,"docs":{},"s":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"df":1,"docs":{"9":{"tf":1.0}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"r":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"s":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"df":0,"docs":{},"f":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.7320508075688772}}}}},"p":{"df":0,"docs":{},"r":{"df":0,"docs":{},"o":{"d":{"df":0,"docs":{},"u":{"c":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"q":{"df":0,"docs":{},"u":{"df":0,"docs":{},"i":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}}}},"s":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.0}}}}}}},"h":{"df":1,"docs":{"14":{"tf":1.0}}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"t":{"df":2,"docs":{"10":{"tf":2.23606797749979},"14":{"tf":1.0}}}},"w":{"df":1,"docs":{"7":{"tf":1.0}}}},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"2":{"tf":1.7320508075688772}}}}}},"s":{".":{"df":0,"docs":{},"t":{"df":2,"docs":{"12":{"tf":1.0},"13":{"tf":1.0}}}},"=":{"3":{"2":{"df":1,"docs":{"9":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"a":{"df":0,"docs":{},"r":{"df":0,"docs":{},"k":{"a":{"df":0,"docs":{},"r":{"2":{"0":{"2":{"0":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":1,"docs":{"10":{"tf":1.0}}}},"df":0,"docs":{}}}},"c":{"a":{"df":0,"docs":{},"l":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{},"e":{"a":{"df":0,"docs":{},"r":{"c":{"df":0,"docs":{},"h":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"t":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}}},"df":0,"docs":{}}}},"h":{"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"l":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"df":1,"docs":{"9":{"tf":1.0}}}}}}}}},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"h":{"df":0,"docs":{},"t":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}}},"p":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"i":{"df":0,"docs":{},"f":{"df":1,"docs":{"7":{"tf":1.0}}}}},"df":0,"docs":{}},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"q":{"df":0,"docs":{},"u":{"a":{"df":0,"docs":{},"r":{"df":2,"docs":{"10":{"tf":2.449489742783178},"14":{"tf":1.4142135623730951}}}},"df":0,"docs":{}}},"t":{"a":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{}},"u":{"b":{"df":0,"docs":{},"g":{"df":0,"docs":{},"r":{"df":0,"docs":{},"o":{"df":0,"docs":{},"u":{"df":0,"docs":{},"p":{"df":3,"docs":{"10":{"tf":1.4142135623730951},"3":{"tf":1.0},"9":{"tf":1.0}}}}}}},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}}},"c":{"df":0,"docs":{},"h":{"df":2,"docs":{"11":{"tf":1.0},"14":{"tf":1.0}}}},"df":0,"docs":{},"p":{"df":0,"docs":{},"p":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"2":{"tf":1.4142135623730951}}}},"s":{"df":1,"docs":{"10":{"tf":1.0}}}}}}},"y":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}},"t":{"0":{"df":1,"docs":{"11":{"tf":1.0}}},"1":{"df":1,"docs":{"12":{"tf":1.0}}},"2":{"df":1,"docs":{"13":{"tf":1.0}}},"3":{"df":1,"docs":{"14":{"tf":1.0}}},"=":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"+":{"2":{"2":{"4":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"3":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"a":{"b":{"df":0,"docs":{},"l":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"7":{"tf":1.4142135623730951}}}},"df":0,"docs":{},"s":{"df":0,"docs":{},"k":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":1,"docs":{"9":{"tf":1.0}},"e":{"c":{"df":0,"docs":{},"h":{"df":0,"docs":{},"n":{"df":0,"docs":{},"i":{"df":0,"docs":{},"q":{"df":0,"docs":{},"u":{"df":1,"docs":{"10":{"tf":1.0}}}}}}}},"df":0,"docs":{},"r":{"df":0,"docs":{},"m":{"df":2,"docs":{"5":{"tf":1.0},"7":{"tf":1.0}}}}},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"f":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":1,"docs":{"14":{"tf":1.0}}}}}}},"y":{"'":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"k":{"df":1,"docs":{"7":{"tf":1.0}}}}},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"e":{"df":1,"docs":{"14":{"tf":1.0}}}}}},"o":{"d":{"df":0,"docs":{},"o":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}},"w":{"df":0,"docs":{},"o":{"df":1,"docs":{"3":{"tf":1.0}}}}},"u":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"14":{"tf":1.0}},"n":{"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"4":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":1,"docs":{"10":{"tf":1.0}}}}},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"df":0,"docs":{},"s":{"df":1,"docs":{"5":{"tf":1.0}}}}}}},"p":{"d":{"a":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{}},"s":{"df":5,"docs":{"10":{"tf":1.0},"11":{"tf":1.0},"14":{"tf":1.0},"3":{"tf":1.0},"7":{"tf":1.7320508075688772}},"u":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"l":{"df":1,"docs":{"3":{"tf":1.0}}}}},"v":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"/":{"2":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"v":{"=":{"df":0,"docs":{},"u":{"(":{"df":0,"docs":{},"t":{"df":0,"docs":{},"−":{"1":{")":{"/":{"2":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"a":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"s":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":2,"docs":{"2":{"tf":1.7320508075688772},"4":{"tf":1.0}}}}}}},"s":{"df":0,"docs":{},"t":{"a":{"df":3,"docs":{"0":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}}}},"−":{"1":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"/":{"2":{")":{"2":{"=":{"df":0,"docs":{},"v":{"df":0,"docs":{},"−":{"2":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"=":{"df":0,"docs":{},"u":{"df":1,"docs":{"14":{"tf":1.0}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"w":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"’":{"df":0,"docs":{},"v":{"df":1,"docs":{"3":{"tf":1.0}}}}},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}},"i":{"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"o":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}}}}},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"k":{"df":1,"docs":{"5":{"tf":1.0}}}}},"r":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":2,"docs":{"14":{"tf":1.0},"9":{"tf":1.0}}}}}}},"x":{"0":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"2":{"2":{"4":{"=":{"1":{"df":1,"docs":{"11":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"3":{"df":1,"docs":{"3":{"tf":1.4142135623730951}},"​":{"=":{"df":0,"docs":{},"x":{",":{"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"=":{"df":0,"docs":{},"x":{"3":{"2":{"8":{"df":0,"docs":{},"​":{",":{"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"=":{"df":0,"docs":{},"x":{"2":{"2":{"8":{"df":0,"docs":{},"​":{",":{"df":0,"docs":{},"x":{"0":{"df":0,"docs":{},"​":{"=":{"df":0,"docs":{},"x":{"1":{"2":{"8":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"=":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"​":{"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"2":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"/":{"2":{"df":0,"docs":{},"​":{"=":{"=":{"=":{"=":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"df":0,"docs":{},"v":{"df":0,"docs":{},"−":{"1":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"df":0,"docs":{},"v":{"df":0,"docs":{},"−":{"1":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"/":{"2":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}}}}},"df":0,"docs":{}}}}}}}}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}}}}}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"=":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"v":{"=":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}},"y":{"2":{"df":1,"docs":{"3":{"tf":1.4142135623730951}}},"df":0,"docs":{}},"z":{"df":1,"docs":{"10":{"tf":1.0}},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"o":{"df":1,"docs":{"10":{"tf":1.0}}}}},"p":{"df":1,"docs":{"10":{"tf":1.4142135623730951}}}}}},"breadcrumbs":{"root":{"0":{"df":1,"docs":{"11":{"tf":1.4142135623730951}}},"1":{".":{"5":{"6":{"df":1,"docs":{"2":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":1,"docs":{"11":{"tf":1.4142135623730951}},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"(":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{")":{"df":0,"docs":{},"⋅":{"2":{"1":{"6":{"=":{"1":{"df":1,"docs":{"12":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"df":0,"docs":{},"t":{"0":{"df":1,"docs":{"11":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"2":{".":{"0":{"df":2,"docs":{"4":{"tf":1.4142135623730951},"5":{"tf":1.0}}},"df":0,"docs":{}},"df":3,"docs":{"12":{"tf":1.4142135623730951},"3":{"tf":1.0},"9":{"tf":1.0}},"s":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"9":{"tf":1.0}}},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"(":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{")":{"df":0,"docs":{},"⋅":{"2":{"8":{"=":{"1":{"df":1,"docs":{"13":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":1,"docs":{"12":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"3":{"df":1,"docs":{"13":{"tf":1.4142135623730951}},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"+":{"2":{"2":{"4":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"3":{"df":0,"docs":{},"​":{"=":{"1":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":1,"docs":{"13":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"5":{"df":1,"docs":{"3":{"tf":1.4142135623730951}}},"a":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"a":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"+":{"b":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"b":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"+":{"a":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"b":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"df":0,"docs":{},"m":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"+":{"c":{"(":{"df":0,"docs":{},"x":{")":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"q":{"c":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"x":{")":{"=":{"0":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"b":{"df":0,"docs":{},"o":{"df":0,"docs":{},"v":{"df":1,"docs":{"5":{"tf":1.0}}}}},"d":{"d":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"c":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}},"v":{"df":0,"docs":{},"i":{"c":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{},"l":{"df":0,"docs":{},"g":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"m":{"df":1,"docs":{"10":{"tf":1.7320508075688772}}}}}}}}}},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"p":{"a":{"c":{"df":0,"docs":{},"h":{"df":2,"docs":{"4":{"tf":1.4142135623730951},"5":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{}},"r":{"df":0,"docs":{},"g":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}}}},"b":{"a":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"3":{"tf":1.0}}}}},"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}},"h":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}}}}},"l":{"df":0,"docs":{},"o":{"df":0,"docs":{},"g":{"df":1,"docs":{"0":{"tf":1.0}}}}},"o":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":1,"docs":{"9":{"tf":1.0}}}}},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":1,"docs":{"2":{"tf":1.0}}}}}},"c":{"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}},"h":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"g":{"df":1,"docs":{"2":{"tf":1.0}}}}},"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"k":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"o":{"d":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{},"l":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"n":{"df":1,"docs":{"7":{"tf":2.0}}}}}},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"14":{"tf":1.4142135623730951}}}}}},"n":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}}}},"d":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{},"s":{"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}}},"t":{"df":0,"docs":{},"r":{"a":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}}},"df":0,"docs":{},"u":{"c":{"df":0,"docs":{},"t":{"df":1,"docs":{"0":{"tf":1.0}}}},"df":0,"docs":{}}}}},"t":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"b":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.7320508075688772}}}}},"df":0,"docs":{}},"o":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}}}}},"r":{"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"df":0,"docs":{},"p":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}}}}}}}}},"r":{"a":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"0":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"c":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}}}}},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":3,"docs":{"0":{"tf":1.4142135623730951},"3":{"tf":2.449489742783178},"9":{"tf":1.0}}}}},"y":{"c":{"df":0,"docs":{},"l":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":5,"docs":{"10":{"tf":1.4142135623730951},"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"5":{"tf":1.0}}}}},"s":{"c":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"b":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.4142135623730951}}}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"n":{"df":10,"docs":{"10":{"tf":1.0},"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"14":{"tf":1.0},"3":{"tf":1.0},"6":{"tf":1.7320508075688772},"7":{"tf":1.0},"8":{"tf":1.0},"9":{"tf":1.4142135623730951}}}}}},"t":{"a":{"df":0,"docs":{},"i":{"df":0,"docs":{},"l":{"df":1,"docs":{"0":{"tf":1.0}}}}},"df":0,"docs":{}}},"i":{"df":0,"docs":{},"f":{"df":0,"docs":{},"f":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}}}}},"o":{"c":{"df":1,"docs":{"7":{"tf":1.0}},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"1":{"tf":1.4142135623730951}}}}}}}},"df":0,"docs":{},"n":{"df":0,"docs":{},"e":{"df":1,"docs":{"2":{"tf":1.0}}}}},"u":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"5":{"tf":1.0}}}},"df":0,"docs":{}}},"df":0,"docs":{},"e":{"a":{"c":{"df":0,"docs":{},"h":{"df":4,"docs":{"10":{"tf":1.0},"3":{"tf":1.4142135623730951},"7":{"tf":1.0},"9":{"tf":1.0}}}},"df":0,"docs":{},"r":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"14":{"tf":1.0}}}}}}}},"df":0,"docs":{},"f":{"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}}},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}}},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"0":{"tf":1.0}}}}}}},"n":{"a":{"b":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{},"t":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"df":1,"docs":{"7":{"tf":1.0}}}}}},"s":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}},"x":{"a":{"c":{"df":0,"docs":{},"t":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"df":0,"docs":{}},"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}}},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":1,"docs":{"5":{"tf":1.0}}}}}}},"df":0,"docs":{}}}}}},"f":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"d":{"df":7,"docs":{"10":{"tf":1.0},"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"14":{"tf":1.0},"3":{"tf":1.7320508075688772},"9":{"tf":2.23606797749979}}},"df":0,"docs":{}}},"n":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"14":{"tf":1.4142135623730951}}}},"d":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"r":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.0}}}}},"x":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}},"o":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":0,"docs":{},"o":{"df":0,"docs":{},"w":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"r":{"df":0,"docs":{},"m":{"df":1,"docs":{"3":{"tf":1.0}}}},"u":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"0":{"tf":1.0}}},"df":0,"docs":{}}}},"u":{"df":0,"docs":{},"t":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}}}}},"g":{"=":{"df":0,"docs":{},"z":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"a":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}}},"df":0,"docs":{},"f":{"(":{"0":{"df":0,"docs":{},"x":{"4":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"2":{"2":{"4":{"6":{"9":{"8":{"df":0,"docs":{},"f":{"c":{"0":{"9":{"4":{"c":{"df":0,"docs":{},"f":{"9":{"1":{"b":{"9":{"9":{"2":{"d":{"3":{"0":{"df":0,"docs":{},"e":{"d":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"1":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"9":{"4":{"a":{"8":{"d":{"d":{"8":{"c":{"4":{"6":{"df":0,"docs":{},"e":{"b":{"2":{"1":{"0":{"0":{"0":{"0":{"0":{"0":{"0":{"1":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"t":{"a":{"b":{"=":{"df":0,"docs":{},"⎣":{"df":0,"docs":{},"⎡":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"0":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"0":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"0":{"(":{"df":0,"docs":{},"g":{"2":{"2":{"4":{")":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"2":{"4":{")":{"1":{"df":0,"docs":{},"​":{".":{".":{".":{".":{".":{".":{".":{".":{".":{".":{".":{".":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"8":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"1":{"6":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"(":{"df":0,"docs":{},"g":{"2":{"2":{"4":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"df":0,"docs":{},"p":{"df":1,"docs":{"9":{"tf":1.0}}}},"r":{"df":0,"docs":{},"e":{"'":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}}}},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}},"l":{"df":0,"docs":{},"i":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}}}}},"t":{"df":0,"docs":{},"t":{"df":0,"docs":{},"p":{":":{"/":{"/":{"df":0,"docs":{},"o":{"df":0,"docs":{},"p":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":0,"docs":{},"o":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"c":{"df":0,"docs":{},"e":{".":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"g":{"/":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"/":{"df":0,"docs":{},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"4":{"tf":1.0}}}}}},"df":0,"docs":{}}}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}}}}}}}}},"w":{"df":0,"docs":{},"w":{"df":0,"docs":{},"w":{".":{"a":{"df":0,"docs":{},"p":{"a":{"c":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{".":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"g":{"/":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"/":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":1,"docs":{"4":{"tf":1.0}}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":8,"docs":{"0":{"tf":1.0},"10":{"tf":1.0},"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"14":{"tf":1.0},"8":{"tf":1.7320508075688772},"9":{"tf":1.4142135623730951}}}}}}}},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"n":{"c":{"df":0,"docs":{},"l":{"df":0,"docs":{},"u":{"df":0,"docs":{},"s":{"df":1,"docs":{"5":{"tf":1.0}}}}}},"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"a":{"d":{"df":1,"docs":{"7":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}},"t":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"5":{"tf":1.0}}}}}}}},"u":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"v":{"df":0,"docs":{},"t":{"a":{"b":{"=":{"[":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"0":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"1":{"df":0,"docs":{},"​":{".":{".":{".":{"df":0,"docs":{},"​":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"2":{"8":{"df":0,"docs":{},"−":{"1":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":1,"docs":{"11":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"l":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"g":{"df":0,"docs":{},"u":{"a":{"df":0,"docs":{},"g":{"df":1,"docs":{"7":{"tf":1.7320508075688772}}}},"df":0,"docs":{}}}},"r":{"df":0,"docs":{},"g":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":2,"docs":{"4":{"tf":2.6457513110645907},"5":{"tf":1.4142135623730951}}}}}},"df":0,"docs":{}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"k":{"df":0,"docs":{},"u":{"df":0,"docs":{},"p":{"df":4,"docs":{"11":{"tf":1.0},"12":{"tf":1.0},"13":{"tf":1.0},"14":{"tf":1.4142135623730951}}}}}}}},"m":{"a":{"df":0,"docs":{},"t":{"c":{"df":0,"docs":{},"h":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"df":0,"docs":{},"e":{"a":{"df":0,"docs":{},"n":{"df":2,"docs":{"3":{"tf":1.0},"9":{"tf":1.0}}}},"df":0,"docs":{}},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":1,"docs":{"2":{"tf":1.7320508075688772}}}}}},"o":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}}},"t":{"df":1,"docs":{"4":{"tf":1.4142135623730951}}}},"o":{"d":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"o":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":1,"docs":{"0":{"tf":1.0}}}}},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"p":{"df":0,"docs":{},"l":{"df":4,"docs":{"10":{"tf":1.4142135623730951},"14":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}}}}}}}},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"10":{"tf":1.4142135623730951}}},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}},"w":{"df":1,"docs":{"14":{"tf":1.0}}}}},"o":{"b":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":1,"docs":{"14":{"tf":1.0}}}}}},"t":{"a":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":1,"docs":{"3":{"tf":1.0}}}}},"df":0,"docs":{}}},"d":{"d":{"df":1,"docs":{"9":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{},"n":{"df":2,"docs":{"10":{"tf":1.0},"3":{"tf":1.0}}},"p":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"4":{"tf":1.0}}}}}}},"r":{"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}}},"df":0,"docs":{}},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}},"w":{"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":1,"docs":{"5":{"tf":1.0}}}}}}}}},"v":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.7320508075688772}},"v":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"w":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}}}},"p":{"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"a":{"df":3,"docs":{"0":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}}},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.4142135623730951}},"i":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}}},"df":0,"docs":{}}}},"s":{"df":0,"docs":{},"t":{"a":{"_":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":2,"docs":{"0":{"tf":1.4142135623730951},"10":{"tf":1.0}}}}}},"df":0,"docs":{}},"df":8,"docs":{"0":{"tf":1.7320508075688772},"1":{"tf":1.0},"10":{"tf":1.0},"2":{"tf":1.0},"3":{"tf":1.4142135623730951},"4":{"tf":1.0},"5":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}}}},"df":1,"docs":{"10":{"tf":1.0}},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"f":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"m":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}},"l":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":0,"docs":{},"k":{"df":2,"docs":{"3":{"tf":1.0},"7":{"tf":1.4142135623730951}}}}}},"o":{"df":0,"docs":{},"l":{"df":0,"docs":{},"y":{"df":0,"docs":{},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"m":{"df":0,"docs":{},"i":{"df":2,"docs":{"3":{"tf":1.0},"7":{"tf":1.4142135623730951}}}}}}}},"p":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}}},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"0":{"tf":1.0}}}},"w":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"r":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}}}},"df":0,"docs":{}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":1,"docs":{"10":{"tf":1.0}}}}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"f":{"df":1,"docs":{"3":{"tf":1.0}}}},"p":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"t":{"df":0,"docs":{},"o":{"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"l":{"df":1,"docs":{"3":{"tf":1.0}}}}},"df":0,"docs":{}}},"v":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}},"i":{"d":{"df":1,"docs":{"0":{"tf":1.0}}},"df":0,"docs":{}}}}},"u":{"b":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"s":{"df":0,"docs":{},"h":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"df":0,"docs":{}},"−":{"1":{"df":0,"docs":{},"≡":{"2":{"df":0,"docs":{},"s":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"df":1,"docs":{"9":{"tf":1.0}}}}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"r":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"s":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"df":0,"docs":{},"f":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.7320508075688772}}}}},"p":{"df":0,"docs":{},"r":{"df":0,"docs":{},"o":{"d":{"df":0,"docs":{},"u":{"c":{"df":1,"docs":{"3":{"tf":1.0}}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"q":{"df":0,"docs":{},"u":{"df":0,"docs":{},"i":{"df":0,"docs":{},"r":{"df":1,"docs":{"2":{"tf":1.0}}}}}},"s":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.4142135623730951}}}}}}},"h":{"df":1,"docs":{"14":{"tf":1.0}}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"t":{"df":2,"docs":{"10":{"tf":2.449489742783178},"14":{"tf":1.0}}}},"w":{"df":1,"docs":{"7":{"tf":1.0}}}},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"2":{"tf":2.0}}}}}},"s":{".":{"df":0,"docs":{},"t":{"df":2,"docs":{"12":{"tf":1.0},"13":{"tf":1.0}}}},"=":{"3":{"2":{"df":1,"docs":{"9":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"a":{"df":0,"docs":{},"r":{"df":0,"docs":{},"k":{"a":{"df":0,"docs":{},"r":{"2":{"0":{"2":{"0":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":1,"docs":{"10":{"tf":1.4142135623730951}}}},"df":0,"docs":{}}}},"c":{"a":{"df":0,"docs":{},"l":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{},"e":{"a":{"df":0,"docs":{},"r":{"c":{"df":0,"docs":{},"h":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"d":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"t":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.4142135623730951}}}}}},"df":0,"docs":{}}}},"h":{"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"l":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"l":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"3":{"tf":1.0}}}},"df":0,"docs":{}}},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"df":1,"docs":{"9":{"tf":1.0}}}}}}}}},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"h":{"df":0,"docs":{},"t":{"df":0,"docs":{},"l":{"df":0,"docs":{},"i":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}}},"p":{"df":0,"docs":{},"e":{"c":{"df":0,"docs":{},"i":{"df":0,"docs":{},"f":{"df":1,"docs":{"7":{"tf":1.0}}}}},"df":0,"docs":{}},"l":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}}},"q":{"df":0,"docs":{},"u":{"a":{"df":0,"docs":{},"r":{"df":2,"docs":{"10":{"tf":2.6457513110645907},"14":{"tf":1.4142135623730951}}}},"df":0,"docs":{}}},"t":{"a":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{}},"u":{"b":{"df":0,"docs":{},"g":{"df":0,"docs":{},"r":{"df":0,"docs":{},"o":{"df":0,"docs":{},"u":{"df":0,"docs":{},"p":{"df":3,"docs":{"10":{"tf":1.4142135623730951},"3":{"tf":1.0},"9":{"tf":1.0}}}}}}},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}}},"c":{"df":0,"docs":{},"h":{"df":2,"docs":{"11":{"tf":1.0},"14":{"tf":1.0}}}},"df":0,"docs":{},"p":{"df":0,"docs":{},"p":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"2":{"tf":1.7320508075688772}}}},"s":{"df":1,"docs":{"10":{"tf":1.0}}}}}}},"y":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":1,"docs":{"3":{"tf":1.0}}}}}}}},"t":{"0":{"df":1,"docs":{"11":{"tf":1.0}}},"1":{"df":1,"docs":{"12":{"tf":1.0}}},"2":{"df":1,"docs":{"13":{"tf":1.0}}},"3":{"df":1,"docs":{"14":{"tf":1.0}}},"=":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"+":{"2":{"8":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"1":{"df":0,"docs":{},"​":{"+":{"2":{"1":{"6":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"2":{"df":0,"docs":{},"​":{"+":{"2":{"2":{"4":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"t":{"3":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"a":{"b":{"df":0,"docs":{},"l":{"df":2,"docs":{"10":{"tf":1.7320508075688772},"7":{"tf":1.4142135623730951}}}},"df":0,"docs":{},"s":{"df":0,"docs":{},"k":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":1,"docs":{"9":{"tf":1.0}},"e":{"c":{"df":0,"docs":{},"h":{"df":0,"docs":{},"n":{"df":0,"docs":{},"i":{"df":0,"docs":{},"q":{"df":0,"docs":{},"u":{"df":1,"docs":{"10":{"tf":1.0}}}}}}}},"df":0,"docs":{},"r":{"df":0,"docs":{},"m":{"df":2,"docs":{"5":{"tf":1.0},"7":{"tf":1.0}}}}},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"f":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":1,"docs":{"14":{"tf":1.0}}}}}}},"y":{"'":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"k":{"df":1,"docs":{"7":{"tf":1.0}}}}},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"e":{"df":1,"docs":{"14":{"tf":1.0}}}}}},"o":{"d":{"df":0,"docs":{},"o":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}},"w":{"df":0,"docs":{},"o":{"df":1,"docs":{"3":{"tf":1.0}}}}},"u":{"df":2,"docs":{"10":{"tf":1.4142135623730951},"14":{"tf":1.0}},"n":{"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"4":{"tf":1.0}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"i":{"df":1,"docs":{"10":{"tf":1.0}}}}},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"df":0,"docs":{},"s":{"df":1,"docs":{"5":{"tf":1.0}}}}}}},"p":{"d":{"a":{"df":0,"docs":{},"t":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{}},"s":{"df":5,"docs":{"10":{"tf":1.0},"11":{"tf":1.0},"14":{"tf":1.0},"3":{"tf":1.0},"7":{"tf":1.7320508075688772}},"u":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}},"t":{"df":0,"docs":{},"i":{"df":0,"docs":{},"l":{"df":1,"docs":{"3":{"tf":1.0}}}}},"v":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"/":{"2":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"v":{"=":{"df":0,"docs":{},"u":{"(":{"df":0,"docs":{},"t":{"df":0,"docs":{},"−":{"1":{")":{"/":{"2":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}}},"a":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.4142135623730951}}}}},"df":0,"docs":{}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"s":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":2,"docs":{"2":{"tf":2.0},"4":{"tf":1.0}}}}}}},"s":{"df":0,"docs":{},"t":{"a":{"df":3,"docs":{"0":{"tf":1.0},"3":{"tf":1.0},"9":{"tf":1.0}}},"df":0,"docs":{}}}},"−":{"1":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"/":{"2":{")":{"2":{"=":{"df":0,"docs":{},"v":{"df":0,"docs":{},"−":{"2":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"=":{"df":0,"docs":{},"u":{"df":1,"docs":{"14":{"tf":1.0}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"w":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"’":{"df":0,"docs":{},"v":{"df":1,"docs":{"3":{"tf":1.0}}}}},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":1,"docs":{"7":{"tf":1.0}}}}}}}},"i":{"df":0,"docs":{},"r":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"o":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}}}}},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"k":{"df":1,"docs":{"5":{"tf":1.0}}}}},"r":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":2,"docs":{"14":{"tf":1.0},"9":{"tf":1.0}}}}}}},"x":{"0":{"df":0,"docs":{},"​":{"=":{"(":{"df":0,"docs":{},"g":{"2":{"df":0,"docs":{},"−":{"2":{"4":{")":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"x":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"0":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⋅":{"2":{"2":{"4":{"=":{"1":{"df":1,"docs":{"11":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}},"3":{"df":1,"docs":{"3":{"tf":1.4142135623730951}},"​":{"=":{"df":0,"docs":{},"x":{",":{"df":0,"docs":{},"x":{"2":{"df":0,"docs":{},"​":{"=":{"df":0,"docs":{},"x":{"3":{"2":{"8":{"df":0,"docs":{},"​":{",":{"df":0,"docs":{},"x":{"1":{"df":0,"docs":{},"​":{"=":{"df":0,"docs":{},"x":{"2":{"2":{"8":{"df":0,"docs":{},"​":{",":{"df":0,"docs":{},"x":{"0":{"df":0,"docs":{},"​":{"=":{"df":0,"docs":{},"x":{"1":{"2":{"8":{"df":1,"docs":{"10":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{}}},"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"=":{"1":{"df":0,"docs":{},"​":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"⟹":{"df":0,"docs":{},"​":{"df":0,"docs":{},"x":{"3":{"df":0,"docs":{},"​":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"2":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"t":{"/":{"2":{"df":0,"docs":{},"​":{"=":{"=":{"=":{"=":{"df":0,"docs":{},"​":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"df":0,"docs":{},"v":{"df":0,"docs":{},"−":{"1":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"df":0,"docs":{},"v":{"df":0,"docs":{},"−":{"1":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"g":{"df":0,"docs":{},"−":{"df":0,"docs":{},"t":{"/":{"2":{"df":1,"docs":{"14":{"tf":1.0}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"df":0,"docs":{}}}}}}}},"df":0,"docs":{}}}}}}}}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}}}}},"df":0,"docs":{}}}}},"df":0,"docs":{}}}}}}}}},"df":0,"docs":{}},"df":0,"docs":{}}}}}},"=":{"df":0,"docs":{},"u":{"df":0,"docs":{},"v":{"df":0,"docs":{},"⋅":{"df":0,"docs":{},"v":{"=":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{}}}}}},"df":0,"docs":{}},"y":{"2":{"df":1,"docs":{"3":{"tf":1.4142135623730951}}},"df":0,"docs":{}},"z":{"df":1,"docs":{"10":{"tf":1.0}},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"o":{"df":1,"docs":{"10":{"tf":1.0}}}}},"p":{"df":1,"docs":{"10":{"tf":1.4142135623730951}}}}}},"title":{"root":{"0":{"df":1,"docs":{"11":{"tf":1.0}}},"1":{"df":1,"docs":{"11":{"tf":1.0}}},"2":{"df":1,"docs":{"12":{"tf":1.0}}},"3":{"df":1,"docs":{"13":{"tf":1.0}}},"a":{"df":0,"docs":{},"l":{"df":0,"docs":{},"g":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"df":0,"docs":{},"t":{"df":0,"docs":{},"h":{"df":0,"docs":{},"m":{"df":1,"docs":{"10":{"tf":1.0}}}}}}}}}}},"b":{"a":{"df":0,"docs":{},"s":{"df":0,"docs":{},"e":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{}},"c":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"b":{"df":0,"docs":{},"u":{"df":0,"docs":{},"t":{"df":1,"docs":{"5":{"tf":1.0}}}}},"df":0,"docs":{}}}}}},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":1,"docs":{"3":{"tf":1.0}}}}}},"d":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"c":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"df":0,"docs":{},"p":{"df":0,"docs":{},"t":{"df":1,"docs":{"3":{"tf":1.0}}}}}}},"df":0,"docs":{},"i":{"df":0,"docs":{},"g":{"df":0,"docs":{},"n":{"df":1,"docs":{"6":{"tf":1.0}}}}}}},"o":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"1":{"tf":1.0}}}}}}}},"df":0,"docs":{}}},"df":0,"docs":{},"f":{"df":0,"docs":{},"i":{"df":0,"docs":{},"e":{"df":0,"docs":{},"l":{"d":{"df":1,"docs":{"9":{"tf":1.0}}},"df":0,"docs":{}}},"n":{"a":{"df":0,"docs":{},"l":{"df":1,"docs":{"14":{"tf":1.0}}}},"df":0,"docs":{}}}},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"p":{"df":0,"docs":{},"l":{"df":0,"docs":{},"e":{"df":0,"docs":{},"m":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"8":{"tf":1.0}}}}}}}}}}},"l":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"g":{"df":0,"docs":{},"u":{"a":{"df":0,"docs":{},"g":{"df":1,"docs":{"7":{"tf":1.0}}}},"df":0,"docs":{}}}}},"df":0,"docs":{},"i":{"c":{"df":0,"docs":{},"e":{"df":0,"docs":{},"n":{"df":0,"docs":{},"s":{"df":1,"docs":{"4":{"tf":1.0}}}}}},"df":0,"docs":{}}},"m":{"df":0,"docs":{},"i":{"df":0,"docs":{},"n":{"df":0,"docs":{},"i":{"df":0,"docs":{},"m":{"df":0,"docs":{},"u":{"df":0,"docs":{},"m":{"df":1,"docs":{"2":{"tf":1.0}}}}}}}}},"n":{"df":0,"docs":{},"o":{"df":0,"docs":{},"t":{"df":0,"docs":{},"e":{"df":1,"docs":{"7":{"tf":1.0}}}}}},"p":{"a":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"a":{"_":{"c":{"df":0,"docs":{},"u":{"df":0,"docs":{},"r":{"df":0,"docs":{},"v":{"df":1,"docs":{"0":{"tf":1.0}}}}}},"df":0,"docs":{}},"df":0,"docs":{}},"df":0,"docs":{}}}},"df":0,"docs":{}},"r":{"df":0,"docs":{},"e":{"df":0,"docs":{},"s":{"df":0,"docs":{},"u":{"df":0,"docs":{},"l":{"df":0,"docs":{},"t":{"df":1,"docs":{"14":{"tf":1.0}}}}}}},"o":{"df":0,"docs":{},"o":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"u":{"df":0,"docs":{},"s":{"df":0,"docs":{},"t":{"df":1,"docs":{"2":{"tf":1.0}}}}}},"s":{"a":{"df":0,"docs":{},"r":{"df":0,"docs":{},"k":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"10":{"tf":1.0}}}},"df":0,"docs":{}}}},"df":0,"docs":{},"q":{"df":0,"docs":{},"u":{"a":{"df":0,"docs":{},"r":{"df":1,"docs":{"10":{"tf":1.0}}}},"df":0,"docs":{}}},"u":{"df":0,"docs":{},"p":{"df":0,"docs":{},"p":{"df":0,"docs":{},"o":{"df":0,"docs":{},"r":{"df":0,"docs":{},"t":{"df":1,"docs":{"2":{"tf":1.0}}}}}}}}},"t":{"a":{"b":{"df":0,"docs":{},"l":{"df":1,"docs":{"10":{"tf":1.0}}}},"df":0,"docs":{}},"df":0,"docs":{}},"v":{"a":{"df":0,"docs":{},"r":{"df":0,"docs":{},"i":{"a":{"df":0,"docs":{},"n":{"df":0,"docs":{},"t":{"df":1,"docs":{"10":{"tf":1.0}}}}},"df":0,"docs":{}}}},"df":0,"docs":{},"e":{"df":0,"docs":{},"r":{"df":0,"docs":{},"s":{"df":0,"docs":{},"i":{"df":0,"docs":{},"o":{"df":0,"docs":{},"n":{"df":1,"docs":{"2":{"tf":1.0}}}}}}}}}}}},"lang":"English","pipeline":["trimmer","stopWordFilter","stemmer"],"ref":"id","version":"0.9.5"},"results_options":{"limit_results":30,"teaser_word_count":30},"search_options":{"bool":"OR","expand":true,"fields":{"body":{"boost":1},"breadcrumbs":{"boost":1},"title":{"boost":2}}}});